@@ -1,6 +1,6 @@
-#' @rdname find_columns
+#' @rdname extract_column_names
 #' @export
-get_columns <- function(data,
+data_select <- function(data,
                         select = NULL,
                         exclude = NULL,
                         ignore_case = FALSE,
@@ -13,6 +13,7 @@ get_columns <- function(data,
     exclude,
     ignore_case = ignore_case,
     regex = regex,
+    allow_rename = TRUE,
     verbose = FALSE
   )
 
@@ -28,12 +29,12 @@ get_columns <- function(data,
 
   out <- data[columns]
 
+  # for named character vectors, we offer the service to directly rename the columns
+  if (!is.null(names(columns))) {
+    colnames(out) <- names(columns)
+  }
+
   # add back attributes
   out <- .replace_attrs(out, a)
   out
 }
-
-
-#' @rdname find_columns
-#' @export
-data_select <- get_columns
