@@ -77,7 +77,6 @@ coef_var.default <- function(x, verbose = TRUE, ...) {
 #'   as the nearest endpoint.
 #' @param remove_na Logical. Should `NA` values be removed before computing (`TRUE`)
 #'   or not (`FALSE`, default)?
-#' @param na.rm Deprecated. Please use `remove_na` instead.
 #' @param n If `method = "unbiased"` and both `mu` and `sigma` are provided (not
 #'   computed from `x`), what sample size to use to adjust the computed CV
 #'   for small-sample bias?
@@ -111,13 +110,7 @@ coef_var.default <- function(x, verbose = TRUE, ...) {
 #' @export
 coef_var.numeric <- function(x, mu = NULL, sigma = NULL,
                              method = c("standard", "unbiased", "median_mad", "qcd"),
-                             trim = 0, remove_na = FALSE, n = NULL, na.rm = FALSE, ...) {
-  # TODO: remove deprecated argument later
-  if (!missing(na.rm)) {
-    insight::format_warning("Argument `na.rm` is deprecated. Please use `remove_na` instead.")
-    remove_na <- na.rm
-  }
-
+                             trim = 0, remove_na = FALSE, n = NULL, ...) {
   # TODO: Support weights
   if (!missing(x) && all(c(-1, 1) %in% sign(x))) {
     insight::format_error("Coefficient of variation only applicable for ratio scale variables.")
@@ -160,8 +153,6 @@ coef_var.numeric <- function(x, mu = NULL, sigma = NULL,
 }
 
 
-
-
 # descriptives helpers
 
 .drop_na <- function(x) {
