@@ -23,7 +23,6 @@ test_that("recode numeric", {
 })
 
 
-
 # Date -----------------------
 
 set.seed(123)
@@ -34,7 +33,6 @@ test_that("recode date", {
 })
 
 
-
 # factor -----------------------
 
 set.seed(123)
@@ -92,7 +90,6 @@ test_that("recode factor", {
 })
 
 
-
 # character -----------------------
 
 set.seed(123)
@@ -108,7 +105,6 @@ test_that("recode character", {
 })
 
 
-
 # data frame -----------------------
 
 set.seed(123)
@@ -121,7 +117,7 @@ d <- data.frame(
 test_that("recode data.frame", {
   out <- recode_values(
     d,
-    recode = list(`1` = 0, `2:3` = 1, `4` = 2, a = "x", `b, c` = "y"),
+    recode = list(`1` = 0, `2:3` = 1, `4` = 2, a = "x", `b, c` = "y")
   )
   expect_equal(
     out,
@@ -140,7 +136,7 @@ test_that("recode data.frame", {
 
   out <- recode_values(
     d,
-    recode = list(`1` = 0, `2:3` = 1, `4` = 2, a = "x", `b, c` = "y"),
+    recode = list(`1` = 0, `2:3` = 1, `4` = 2, a = "x", `b, c` = "y")
   )
   expect_equal(
     out,
@@ -179,7 +175,6 @@ test_that("recode data.frame", {
 })
 
 
-
 # set recode pattern back to default --------------
 
 options(data_recode_pattern = NULL)
@@ -197,7 +192,7 @@ test_that("recode numeric", {
 })
 
 test_that("recode, recode-arg is named list", {
-  expect_warning(expect_equal(recode_values(x, recode = c(`0` = 1, `1` = 2:3, `2` = 4)), x))
+  expect_warning(expect_identical(recode_values(x, recode = c(`0` = 1, `1` = 2:3, `2` = 4)), x))
 })
 
 
@@ -226,7 +221,7 @@ test_that("recode factor", {
 })
 
 test_that("recode, recode-arg is named list", {
-  expect_warning(expect_equal(recode_values(x, recode = c(x = "a", y = "b, c")), x))
+  expect_warning(expect_identical(recode_values(x, recode = c(x = "a", y = "b, c")), x))
 })
 
 
@@ -240,7 +235,7 @@ d <- data.frame(
 test_that("recode data.frame", {
   out <- recode_values(
     d,
-    recode = list(`0` = 1, `1` = 2:3, `2` = 4, x = "a", y = "b, c"),
+    recode = list(`0` = 1, `1` = 2:3, `2` = 4, x = "a", y = "b, c")
   )
   expect_equal(
     out,
@@ -259,7 +254,7 @@ test_that("recode data.frame", {
 
   out <- recode_values(
     d,
-    recode = list(`0` = 1, `1` = 2:3, `2` = 4, x = "a", y = c("b", "c")),
+    recode = list(`0` = 1, `1` = 2:3, `2` = 4, x = "a", y = c("b", "c"))
   )
   expect_equal(
     out,
@@ -299,7 +294,7 @@ test_that("recode data.frame", {
 
 # select helpers ------------------------------
 test_that("recode_values regex", {
-  expect_equal(
+  expect_identical(
     recode_values(iris, select = "ies", regex = TRUE, recode = list(
       Group1 = "setosa", Group2 = "versicolor", Group3 = "virginica"
     )),
