@@ -38,7 +38,6 @@ test_that("reverse, labels preserved", {
 })
 
 
-
 # data_merge -----------------------------------
 
 test_that("data_merge, labels preserved", {
@@ -55,7 +54,6 @@ test_that("data_merge, labels preserved", {
 })
 
 
-
 # data_extract -----------------------------------
 
 test_that("data_extract, labels preserved", {
@@ -80,7 +78,6 @@ test_that("data_extract, labels preserved", {
 })
 
 
-
 # categorize -----------------------------------
 
 test_that("categorize, labels preserved", {
@@ -99,7 +96,6 @@ test_that("categorize, labels preserved", {
 })
 
 
-
 # data_reorder -----------------------------------
 
 test_that("data_reorder, labels preserved", {
@@ -111,7 +107,6 @@ test_that("data_reorder, labels preserved", {
 })
 
 
-
 # data_remove -----------------------------------
 
 test_that("data_remove, labels preserved", {
@@ -123,7 +118,6 @@ test_that("data_remove, labels preserved", {
 })
 
 
-
 # data_rename -----------------------------------
 
 test_that("data_rename, labels preserved", {
@@ -150,7 +144,6 @@ test_that("data_rename, labels preserved", {
 })
 
 
-
 # data_addprefix -----------------------------------
 
 test_that("data_addprefix, labels preserved", {
@@ -170,7 +163,6 @@ test_that("data_addprefix, labels preserved", {
 })
 
 
-
 # data_suffix -----------------------------------
 
 test_that("data_addsuffix, labels preserved", {
@@ -190,7 +182,6 @@ test_that("data_addsuffix, labels preserved", {
 })
 
 
-
 # to_numeric -----------------------------------
 
 test_that("to_numeric, labels preserved", {
@@ -218,7 +209,6 @@ test_that("to_numeric, labels preserved", {
 })
 
 
-
 # data_match -----------------------------------
 
 test_that("data_match, labels preserved", {
@@ -249,7 +239,6 @@ test_that("data_match, labels preserved", {
 })
 
 
-
 # data_filter -----------------------------------
 
 test_that("data_filter, labels preserved", {
@@ -267,7 +256,6 @@ test_that("data_filter, labels preserved", {
 })
 
 
-
 # convert_to_na -----------------------------------
 
 test_that("convert_to_na, labels preserved", {
@@ -310,11 +298,10 @@ test_that("convert_to_na, labels preserved", {
 })
 
 
+# data_select -----------------------------------
 
-# get_columns -----------------------------------
-
-test_that("get_columns, labels preserved", {
-  x <- get_columns(efc, starts_with("c"))
+test_that("data_select, labels preserved", {
+  x <- data_select(efc, starts_with("c"))
   # numeric
   expect_equal(
     attr(x$c12hour, "label", exact = TRUE),
@@ -322,7 +309,7 @@ test_that("get_columns, labels preserved", {
     ignore_attr = TRUE
   )
 
-  x <- get_columns(efc, starts_with("e"))
+  x <- data_select(efc, starts_with("e"))
   # factor
   expect_equal(
     attr(x$e42dep, "label", exact = TRUE),
@@ -332,7 +319,6 @@ test_that("get_columns, labels preserved", {
 })
 
 
-
 # recode_values -----------------------------------
 
 test_that("recode_values, labels preserved", {
@@ -348,7 +334,6 @@ test_that("recode_values, labels preserved", {
 })
 
 
-
 # slide -----------------------------------
 
 test_that("slide, labels preserved", {
@@ -370,7 +355,6 @@ test_that("slide, labels preserved", {
 })
 
 
-
 # to_factor -----------------------------------
 
 test_that("to_factor, labels preserved", {
